SCEtoMatrix.RdThis function takes an SCE and returns its counts matrix. It has additional features, such as adding the column/row names to the data, and subsetting the matrix automatically.
SCEtoMatrix(sce, rowList = NULL, colList = NULL, addRowData = TRUE, addColData = TRUE, transpose = FALSE)
| sce | the sce to format |
|---|---|
| rowList | numeric vector indicating which rows to subset the matrix to. Defaults to NULL |
| colList | numeric vector indicating which cols to subset the matrix to. Defaults to NULL |
| addRowData | logical. Should the function add the original rowdata from the matrix. Defaults to TRUE |
| addColData | logical. Should the function add the original coldata from the matrix. Defaults to TRUE |
| transpose | whether to tranpose the matrix before returning |